#!/bin/bash
#
# analog.sh -- 17Oct13 rjn
#
# reads analog from dacs processor using "read" command sent to serial port
#
# Usage:
# > analog.sh <device> <port speed>
# Example: analog.sh /dev/ttyUSB0 19200
#

# set -x

shopt -s -o nounset  # disallow uninitialed variables

stty -F $1 $2  # set up device

declare RA="read "  # cmd to read analog on P1.2

declare TMP0="/tmp/tmp0.$$" ; touch ${TMP0}
declare TMP1="/tmp/tmp1.$$" ; touch ${TMP1}

date '+%d/%T' >> ${TMP0}

# Let cat read the device $1 in the background
cat $1 >> ${TMP0} &  # background task to relay serial output to stdout (console)

# Capture PID of serial output background task to terminate it when done
bgPid=$?

echo ${RA} > $1  # send the "read" command to the dacs

sleep 0.1  # needs this to allow bg task to complete

head -2 ${TMP0} > ${TMP1}   # get just the date and data, ignore the ">"

# paste the remaining two lines together, append to ana.txt
paste --serial ${TMP1} >> ana.txt

rm ${TMP0} ${TMP1}  # get rid of temp files

kill $bgPid   # Terminate background serial read process

exit 0
